Package: CARMS
Version: 1.0.1
Date: 2024-4-4
Title: Continuous Time Markov Rate Modeling for Reliability Analysis
Authors@R: c(person("David", "Silkworth", email = "djsilk@openreliability.org", role = "aut"), person("Paul", "Pukite", role = "aut"), person("Jacob", "Ormerod", email = "jake@openreliability.org", role = "cre"), person("OpenReliability.org", role = "cph"))
Description: Emulation of an application originally created by Paul Pukite. Computer Aided Rate Modeling and Simulation.  Jan Pukite and Paul Pukite, (1998, ISBN 978-0-7803-3482), William J. Stewart, (1994, ISBN: 0-691-03699-3).
License: GPL (>= 3)
Copyright: copyright (c) OpenReliability.org 2024
URL: http://www.openreliability.org
LazyLoad: yes
Imports: Rcpp, methods, diagram
Author: David Silkworth [aut],
  Paul Pukite [aut],
  Jacob Ormerod [cre],
  OpenReliability.org [cph]
Maintainer: Jacob Ormerod <jake@openreliability.org>
NeedsCompilation: yes
LinkingTo: Rcpp, RcppArmadillo
Packaged: 2024-04-04 15:28:47 UTC; djs
Repository: CRAN
Date/Publication: 2024-04-04 18:03:03 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 13:54:39 UTC; unix
Archs: CARMS.so.dSYM
